package org.artifactory.descriptor.artifact.lifecycle;

import org.apache.commons.lang.StringUtils;
import org.artifactory.descriptor.TaskDescriptor;
import org.jfrog.common.config.diff.DiffKey;
import org.jfrog.common.config.diff.GenerateDiffFunction;
import org.jfrog.common.config.validation.NotUnicode;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import java.util.Objects;

/**
 * @author Tamar Rosen
 */
@XmlType(name = "ArtifactLifecyclePolicyType", propOrder = {"key", "description", "aqlQuery", "cronExp", "type",
        "durationInMinutes"})
@GenerateDiffFunction
@XmlRootElement
public class ArtifactLifecyclePolicyDescriptor implements TaskDescriptor {

    @XmlElement(required = true)
    @DiffKey
    @NotUnicode
    private String key;

    @XmlElement
    @NotUnicode
    private String description;

    @XmlElement(required = true)
    @NotUnicode
    private String aqlQuery;

    @XmlElement(required = true)
    @NotUnicode
    private String cronExp;

    @XmlElement(required = true)
    @NotUnicode
    private String type;

    @XmlElement(defaultValue = "0")
    private long durationInMinutes;

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getAqlQuery() {
        return aqlQuery;
    }

    public void setAqlQuery(String aqlQuery) {
        this.aqlQuery = aqlQuery;
    }

    public String getCronExp() {
        return cronExp;
    }

    public void setCronExp(String cronExp) {
        this.cronExp = cronExp;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public long getDurationInMinutes() {
        return durationInMinutes;
    }

    public void setDurationInMinutes(long durationInMinutes) {
        this.durationInMinutes = durationInMinutes;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) { return true; }
        if (o == null || getClass() != o.getClass()) { return false; }
        ArtifactLifecyclePolicyDescriptor that = (ArtifactLifecyclePolicyDescriptor) o;
        return key.equals(that.key);
    }

    @Override
    public int hashCode() {
        return Objects.hash(key);
    }

    @Override
    public boolean sameTaskDefinition(TaskDescriptor otherDescriptor) {
        if (!(otherDescriptor instanceof ArtifactLifecyclePolicyDescriptor)) {
            throw new IllegalArgumentException("Cannot compare artifact lifecycle descriptor " +
                    this + " with " + otherDescriptor);
        }
        ArtifactLifecyclePolicyDescriptor descriptor = (ArtifactLifecyclePolicyDescriptor) otherDescriptor;
        return StringUtils.equals(descriptor.key, this.key) &&
                StringUtils.equals(descriptor.cronExp, this.cronExp);
    }
}
