package org.artifactory.storage.db.conversion.version.v225;

import org.artifactory.storage.db.version.ConversionPredicate;
import org.jfrog.storage.DbType;
import org.jfrog.storage.JdbcHelper;
import org.jfrog.storage.util.DbUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.sql.SQLException;
import java.util.function.BiPredicate;

/**
 * @author Alexei Vainshtein
 */
public class V225ConversionPredicateBundleFiles implements ConversionPredicate {

    private static final Logger log = LoggerFactory.getLogger(V225ConversionPredicateBundleFiles.class);
    private static final String BUNDLE_FILES_TABLE = "bundle_files";
    private static final String NODE_ID_COLUMN = "node_id";
    private static final String BUNDLE_FILES_NODE_ID_INDEX_NAME = "bundle_files_node_id_idx";

    @Override
    public BiPredicate<JdbcHelper, DbType> condition() {
        return (jdbcHelper, dbType) -> {
            try {
                boolean indexExists = DbUtils.indexExists(jdbcHelper, BUNDLE_FILES_TABLE, NODE_ID_COLUMN,
                        BUNDLE_FILES_NODE_ID_INDEX_NAME, dbType);
                log.debug("Index {} exists: {}", BUNDLE_FILES_NODE_ID_INDEX_NAME, indexExists);
                return !indexExists;
            } catch (SQLException e) {
                log.error("Cannot run conversion 'v225' - Failed to check if index exists: ", e);
            }
            return false;
        };
    }
}
