package org.artifactory.storage.db.conversion.version.v226;

import org.artifactory.storage.db.version.ConversionPredicate;
import org.jfrog.storage.DbType;
import org.jfrog.storage.JdbcHelper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.sql.SQLException;
import java.util.function.BiPredicate;

import static org.jfrog.storage.util.DbUtils.columnExists;

/**
 * @author andreik
 */
public class V226ConversionPredicateBuildsRepoColumn implements ConversionPredicate {

    private static final Logger log = LoggerFactory.getLogger(V226ConversionPredicateBuildsRepoColumn.class);
    private static final String BUILDS_TABLE_NAME = "builds";
    private static final String REPO_COLUMN_NAME = "repo";

    @Override
    public BiPredicate<JdbcHelper, DbType> condition() {
        return (jdbcHelper, dbType) -> {
            try {
                boolean columnExists = columnExists(jdbcHelper, dbType, BUILDS_TABLE_NAME, REPO_COLUMN_NAME);
                log.debug("Column {} in table {} exists: {}", BUILDS_TABLE_NAME, REPO_COLUMN_NAME, columnExists);
                return !columnExists;
            } catch (SQLException e) {
                log.error("Cannot run conversion 'v226' - Failed to check if column exists: ", e);
            }
            return false;
        };
    }
}
