package org.artifactory.storage.db.conversion.version.v227;

import lombok.NonNull;
import org.artifactory.storage.db.conversion.DbConversionException;
import org.artifactory.storage.db.version.ConversionPredicate;
import org.jfrog.storage.DbType;
import org.jfrog.storage.JdbcHelper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.function.BiPredicate;

import static org.jfrog.storage.util.DbUtils.columnExists;

/**
 * @author Volodymyr Shulga
 */
public class V227ConversionPredicate implements ConversionPredicate {

    private static final Logger log = LoggerFactory.getLogger(V227ConversionPredicate.class);

    @NonNull
    @Override
    public BiPredicate<JdbcHelper, DbType> condition() {
        return (jdbcHelper, dbType) -> {
            try {
                // run conversion if column not exist
                if (columnExists(jdbcHelper, dbType, "node_meta_infos", "props_md5")) {
                    log.info("Column 'props_md5' in 'node_meta_infos' table already exist - Skipping upgrade.");
                    return false;
                }
            } catch (Exception e) {
                log.error("Cannot run conversion 'v227' - Failed to retrieve schema metadata");
                throw new DbConversionException(
                        "Cannot run conversion 'v227' - Failed to retrieve schema metadata: " + e.getMessage(), e);
            }
            log.info("Creating column 'props_md5' in 'node_meta_infos' table.");
            return true;
        };
    }
}
