package org.artifactory.storage.db.conversion.version.v233;

import lombok.extern.slf4j.Slf4j;
import org.artifactory.storage.db.conversion.DbConversionException;
import org.artifactory.storage.db.version.ConversionPredicate;
import org.jfrog.storage.DbType;
import org.jfrog.storage.JdbcHelper;
import org.jfrog.storage.util.DbUtils;

import java.util.function.BiPredicate;

import static org.artifactory.storage.db.build.dao.BuildModulesDao.BUILD_MODULES;
import static org.artifactory.storage.db.build.dao.BuildModulesDao.TYPE;
import static org.jfrog.storage.util.DbUtils.withConnection;

@Slf4j
public class V233ConversionPredicate implements ConversionPredicate {

    @Override
    public BiPredicate<JdbcHelper, DbType> condition() {
        return (jdbcHelper, dbType) -> {
            try {
                if (withConnection(jdbcHelper, conn -> DbUtils
                        .columnExists(conn.getMetaData(), dbType, BUILD_MODULES, TYPE))) {
                    log.info("Column '{}' already exists in '{}' table, skipping v233 conversion", TYPE, BUILD_MODULES);
                    return false;
                }
            } catch (Exception e) {
                String message = "Cannot run conversion 'v233' - Failed to retrieve schema metadata: " + e.getMessage();
                log.error(message);
                throw new DbConversionException(message, e);
            }
            log.debug("Column '{}' does not exist in '{}' table, performing v233 conversion", TYPE, BUILD_MODULES);
            return true;
        };
    }

}
